@@ -1,6 +1,6 @@
 package Catmandu::Importer::PICA;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Catmandu::Sane;
 use PICA::Parser::XML;
@@ -23,6 +23,7 @@ sub _build_parser {
     } elsif ( $type eq 'plain') {
         PICA::Parser::Plain->new( $self->fh );
     } elsif ( $type eq 'xml') {
+        $self->{encoding} = ':raw'; # set encoding to :raw to drop PerlIO layers, as required by libxml2
         PICA::Parser::XML->new( $self->fh );
     } else {
         die "unknown type: $type";
@@ -51,7 +52,7 @@ Catmandu::Importer::PICA - Package that imports PICA+ data
     my $importer = Catmandu::Importer::PICA->new(file => "pica.xml", type=> "XML");
 
     my $n = $importer->each(sub {
-        my $hashref = $_[0];
+        my $hashref = shift;
         # ...
     });
 
@@ -59,35 +60,11 @@ To convert between PICA+ syntax variants with the L<catmandu> command line clien
 
     catmandu convert PICA --type xml to PICA --type plain < picadata.xml
 
-=head1 PICA
+=head1 DESCRIPTION
 
-Parse PICA XML to native Perl hash containing two keys: '_id' and 'record'. 
-
-  {
-    'record' => [
-                  [
-                    '001@',
-                    '',
-                    '0',
-                    '703'
-                  ],
-                  [
-                    '001A',
-                    '',
-                    '0',
-                    '2045:10-03-11'
-                  ],
-                  [
-                    '028B',
-                    '01',
-                    'd',
-                    'Thomas',
-                    'a',
-                    'Bartzanas'
-                   ]
-
-    '_id' => '658700774'
-  },
+Parses PICA format to native Perl hash containing two keys C<_id> and
+C<record>. See L<PICA::Data> for more information about PICA data format and
+record structure.
 
 =head1 METHODS
 
